@@ -6,6 +6,7 @@
 #include <memory>
 
 #include <QAbstractListModel>
+#include <QQmlEngine>
 
 class Folder;
 class File;
@@ -16,9 +17,14 @@ namespace Filelight
 class FileModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
     Q_PROPERTY(QUrl url READ url NOTIFY treeChanged /* derives from tree */)
 
 public:
+    static FileModel *instance();
+    static FileModel *create(QQmlEngine *qml, QJSEngine *js);
+
     Q_SIGNAL void treeChanged();
     std::shared_ptr<Folder> m_tree;
 
@@ -35,13 +41,17 @@ public:
     };
     Q_ENUM(Role)
 
-    using QAbstractListModel::QAbstractListModel;
-
     [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
     [[nodiscard]] QVariant data(const QModelIndex &index, int intRole) const override;
     [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
     Q_INVOKABLE [[nodiscard]] std::shared_ptr<File> file(int row) const;
+
+private:
+    // Fun fact: Qt's moc fails to deal with the `using` keyword properly.
+    // If we were using QAbstractListModel::QAbstractListModel it'd not use the
+    // create() function for some reason.
+    explicit FileModel(QObject *parent = nullptr);
 };
 
 } // namespace Filelight
